==> ogre-next-2.2.4-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_material.js <==
var class_ogre_1_1_material =
[
    [ "LodValueArray", "class_ogre_1_1_material.html#a7726f446442e5df77f29e2fd91af1633", null ],
    [ "LodValueIterator", "class_ogre_1_1_material.html#aefc64a391f751ffb3cb5153c3d81bc1b", null ],
    [ "TechniqueIterator", "class_ogre_1_1_material.html#a4969168248bff6aea70eafcf75497689", null ],
    [ "LoadingFlags", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94", [
      [ "LF_DEFAULT", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c", null ],
      [ "LF_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809", null ],
      [ "LF_ONLY_UNREFERENCED", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782", null ],
      [ "LF_ONLY_UNREFERENCED_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77", null ],
      [ "LF_PRESERVE_STATE", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c", null ]
    ] ],
    [ "LoadingState", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572c", [
      [ "LOADSTATE_UNLOADED", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94", null ],
      [ "LOADSTATE_LOADING", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5", null ],
      [ "LOADSTATE_LOADED", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f", null ],
      [ "LOADSTATE_UNLOADING", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e", null ],
      [ "LOADSTATE_PREPARED", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1", null ],
      [ "LOADSTATE_PREPARING", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb", null ]
    ] ],
    [ "Material", "class_ogre_1_1_material.html#ae3c92b81e6c247286c2304f320a368ef", null ],
    [ "~Material", "class_ogre_1_1_material.html#a2e2118319d3d7cb1610869c33ab766eb", null ],
    [ "_dirtyState", "class_ogre_1_1_material.html#afcb4a61b965600a67ca2c2f060821db9", null ],
    [ "_fireLoadingComplete", "class_ogre_1_1_material.html#a893c7a150edb48a25e5df700cfc194eb", null ],
    [ "_firePreparingComplete", "class_ogre_1_1_material.html#a77d5f72e02500f6db6f460bb48eac721", null ],
    [ "_fireUnloadingComplete", "class_ogre_1_1_material.html#a4b5d014a4d078b7893cce480b264c493", null ],
    [ "_getLodValues", "class_ogre_1_1_material.html#ae0740c437d03aabd1da73030aa648539", null ],
    [ "_notifyNeedsRecompile", "class_ogre_1_1_material.html#a66ab9a0f0ef89e66a0f0e0349433af39", null ],
    [ "_notifyOrigin", "class_ogre_1_1_material.html#a3d111616339484f39c9456eeec6fd843", null ],
    [ "addListener", "class_ogre_1_1_material.html#a5513ffce404b14cff72846318b018d32", null ],
    [ "applyTextureAliases", "class_ogre_1_1_material.html#a41f86ef8e5ae9e12ef802b6ff0d4d692", null ],
    [ "changeGroupOwnership", "class_ogre_1_1_material.html#aa5d6f3f7e73b77b233fc62b11f270e4d", null ],
    [ "cleanupDictionary", "class_ogre_1_1_material.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8", null ],
    [ "clone", "class_ogre_1_1_material.html#a28e13cc77ce7deb5f0cbe2388251224d", null ],
    [ "compile", "class_ogre_1_1_material.html#a1f51926064eaa39f9d85393b41bb8870", null ],
    [ "copyDetailsTo", "class_ogre_1_1_material.html#a255bc92a45a8740b388a2b3f0691ee67", null ],
    [ "copyParametersTo", "class_ogre_1_1_material.html#a3c600369ab5d6957524125c93915019f", null ],
    [ "createTechnique", "class_ogre_1_1_material.html#af4238db138727651e692e015e378134a", null ],
    [ "escalateLoading", "class_ogre_1_1_material.html#a367f6fe60bb211cb4c32e3825ca67e4c", null ],
    [ "getBestTechnique", "class_ogre_1_1_material.html#a37ae7259ce89bdc38828ea1b977bdbcf", null ],
    [ "getCompilationRequired", "class_ogre_1_1_material.html#a0473d5bf1469491e9e40a434c4817127", null ],
    [ "getCreator", "class_ogre_1_1_material.html#a741224f735dfd9ce324a4e8e621d868c", null ],
    [ "getGroup", "class_ogre_1_1_material.html#a382919945c07a6a13136889ad3fbf578", null ],
    [ "getHandle", "class_ogre_1_1_material.html#a2298551707debaf774d577e643ee856a", null ],
    [ "getLoadingState", "class_ogre_1_1_material.html#a1e90ade99935ef70ec5b199243bf995b", null ],
    [ "getLodValueIterator", "class_ogre_1_1_material.html#afd936b84ca57f7baba8b20d3fa1db1fc", null ],
    [ "getName", "class_ogre_1_1_material.html#a0646fba8aa0242c6b389d73f47ebe41b", null ],
    [ "getNumLodLevels", "class_ogre_1_1_material.html#a90e332b7e44b66bc34e3b90d810f7f2e", null ],
    [ "getNumLodLevels", "class_ogre_1_1_material.html#a329e758eca8bedadf01edc49f29c5b2e", null ],
    [ "getNumSupportedTechniques", "class_ogre_1_1_material.html#adb809a1006c92bf84746bf145add297e", null ],
    [ "getNumTechniques", "class_ogre_1_1_material.html#a6ee1fe32db9f689a522262922ffa9b39", null ],
    [ "getOrigin", "class_ogre_1_1_material.html#ab298af22eef082938fac77ee9ae7c694", null ],
    [ "getParamDictionary", "class_ogre_1_1_material.html#ae3e13925bde11db245f6c9bbf5031a93", null ],
    [ "getParamDictionary", "class_ogre_1_1_material.html#a0f55da0550a7e1ab70a1c8bf598a3e20", null ],
    [ "getParameter", "class_ogre_1_1_material.html#a01a6e571941916969316ab23c5ee4739", null ],
    [ "getParameters", "class_ogre_1_1_material.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d", null ],
    [ "getReceiveShadows", "class_ogre_1_1_material.html#a75f43a20ac158be5187facacdb4b1f70", null ],
    [ "getSize", "class_ogre_1_1_material.html#a0617d9f04ca03bd25f4bde201e6ac13b", null ],
    [ "getStateCount", "class_ogre_1_1_material.html#ade85e4d5579519e4117a84789c0ae8fd", null ],
    [ "getSupportedTechnique", "class_ogre_1_1_material.html#accfd676f253b906ab3e661b8453465ee", null ],
    [ "getSupportedTechniqueIterator", "class_ogre_1_1_material.html#a96a7e49668804887511eeb1af691ace0", null ],
    [ "getTechnique", "class_ogre_1_1_material.html#a45adc5d6aaebd5b77cfa663fa055eb83", null ],
    [ "getTechnique", "class_ogre_1_1_material.html#abc82b3c4963c8d3cd04c93fdc6dbf416", null ],
    [ "getTechniqueIterator", "class_ogre_1_1_material.html#a2b00231e68df74a029421e1511ae97d6", null ],
    [ "getTransparencyCastsShadows", "class_ogre_1_1_material.html#ab10eb8e63b9e2b39aa2872d84a5be596", null ],
    [ "getUnsupportedTechniquesExplanation", "class_ogre_1_1_material.html#a20a22a23c0f33bcac8141b9ad7a90fe7", null ],
    [ "getUserLodValueIterator", "class_ogre_1_1_material.html#aab7875efbb7e2b0e5fed198469035a31", null ],
    [ "isBackgroundLoaded", "class_ogre_1_1_material.html#a60ce96525ac730a0f7b466ed287beef3", null ],
    [ "isLoaded", "class_ogre_1_1_material.html#a74138c0203835513613af73cdb08890d", null ],
    [ "isLoading", "class_ogre_1_1_material.html#a3af26f716731b64850ea50cfa4d2edef", null ],
    [ "isManuallyLoaded", "class_ogre_1_1_material.html#a8f541900f7e1f73f4c313a732199029a", null ],
    [ "isPrepared", "class_ogre_1_1_material.html#a0779c46df96234b6619a5f57fbb36078", null ],
    [ "isReloadable", "class_ogre_1_1_material.html#a8eb34a9034aab62fd537c021a79e3366", null ],
    [ "isTransparent", "class_ogre_1_1_material.html#a00967b56ec980480ba12dc6002462c3b", null ],
    [ "load", "class_ogre_1_1_material.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
    [ "operator delete", "class_ogre_1_1_material.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_material.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_material.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_material.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_material.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_material.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
    [ "operator new", "class_ogre_1_1_material.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
    [ "operator new", "class_ogre_1_1_material.html#ab78a921e54419be677839cdf15d1f0b8", null ],
    [ "operator new[]", "class_ogre_1_1_material.html#afa2943846ba6a2b5824a12857139cf5e", null ],
    [ "operator new[]", "class_ogre_1_1_material.html#a4be37baef81876985aa1071ad5acc6dd", null ],
    [ "operator=", "class_ogre_1_1_material.html#ada9d917b97ae23bbd61ab8a811dd14cf", null ],
    [ "prepare", "class_ogre_1_1_material.html#a350b287fa3e83a389221274f68760008", null ],
    [ "reload", "class_ogre_1_1_material.html#a5016aec1762b026997ddd346775879ef", null ],
    [ "removeAllTechniques", "class_ogre_1_1_material.html#a1158a82d9399448666ea415d5f9a10a9", null ],
    [ "removeListener", "class_ogre_1_1_material.html#a3c49142f739ba8fb56d6e7b3db235fb7", null ],
    [ "removeTechnique", "class_ogre_1_1_material.html#a8a81c60f958b0f3615c8690583c10d52", null ],
    [ "setAmbient", "class_ogre_1_1_material.html#af2788cd021eba0164ff6020de64d417e", null ],
    [ "setAmbient", "class_ogre_1_1_material.html#a51a76c34cc1ae2a069c6d6440738d291", null ],
    [ "setBackgroundLoaded", "class_ogre_1_1_material.html#ae0a0007de944eb3c2f933a372a752b35", null ],
    [ "setBlendblock", "class_ogre_1_1_material.html#a50c4d80faff3e45ed06b62b7b8c93a9a", null ],
    [ "setColourWriteEnabled", "class_ogre_1_1_material.html#ab88f2abf1ca49a99555820fce32f75a0", null ],
    [ "setDiffuse", "class_ogre_1_1_material.html#ac074b3eb66c45685be8fb4b0ebbebcd6", null ],
    [ "setDiffuse", "class_ogre_1_1_material.html#aebf26724438956ed04cdc0834f088567", null ],
    [ "setFog", "class_ogre_1_1_material.html#a32937d27d1a0211a76d9ce8035a221ee", null ],
    [ "setLodLevels", "class_ogre_1_1_material.html#a968ff717c90173b577501bb9d700c9b3", null ],
    [ "setMacroblock", "class_ogre_1_1_material.html#ac1363fecebbacd68cdbf0f8ddef39c06", null ],
    [ "setManuallyLoaded", "class_ogre_1_1_material.html#a82174dc4f4a0645332483ced7904c2f6", null ],
    [ "setParameter", "class_ogre_1_1_material.html#ace884b65b722ead9b920b9abf27bf815", null ],
    [ "setParameterList", "class_ogre_1_1_material.html#ae356913ccefbebc4f0119a0599a406fc", null ],
    [ "setPointSize", "class_ogre_1_1_material.html#a8c26b7ccb050d96cd031db31bf996b48", null ],
    [ "setReceiveShadows", "class_ogre_1_1_material.html#abe6a4371ce72c7bf1cf5a0c2e9259815", null ],
    [ "setSamplerblock", "class_ogre_1_1_material.html#a135d3f275d4afac7a02c327b3573acaf", null ],
    [ "setSelfIllumination", "class_ogre_1_1_material.html#a27911290eaa7990dea483f62d27c9285", null ],
    [ "setSelfIllumination", "class_ogre_1_1_material.html#a0b498763bb992542e1094a027602b2bf", null ],
    [ "setShadingMode", "class_ogre_1_1_material.html#abe72697aa6f639a23d2003fc10d3939b", null ],
    [ "setShininess", "class_ogre_1_1_material.html#a008c264b3fa918677120621d6a112f99", null ],
    [ "setSpecular", "class_ogre_1_1_material.html#ac0fd7b4c5684270dc61e57ef6ddef4f2", null ],
    [ "setSpecular", "class_ogre_1_1_material.html#a1bb1aed9081702e2b7f65d32be7caad4", null ],
    [ "setToLoaded", "class_ogre_1_1_material.html#a0389e214a82832a0c11d91babbc0d65f", null ],
    [ "setTransparencyCastsShadows", "class_ogre_1_1_material.html#a5552baf6c922eb48a981f7c51aadc5e2", null ],
    [ "touch", "class_ogre_1_1_material.html#a340e9c6140a5b0f3467596712aa122a9", null ],
    [ "unload", "class_ogre_1_1_material.html#aa31bef1bfaa87731622e56f11b548e27", null ],
    [ "MaterialManager", "class_ogre_1_1_material.html#a00bfe1380be4c044551121bbd7fb8359", null ],
    [ "SceneManager", "class_ogre_1_1_material.html#a284464b0561a6f2915f04b0245b987f0", null ],
    [ "OGRE_AUTO_MUTEX", "class_ogre_1_1_material.html#a104d9db8bfcff1f37b29157bbe070f7a", null ]
];

==> ogre-next-2.3.1-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_material.js <==
var class_ogre_1_1_material =
[
    [ "LodValueArray", "class_ogre_1_1_material.html#a7726f446442e5df77f29e2fd91af1633", null ],
    [ "LodValueIterator", "class_ogre_1_1_material.html#aefc64a391f751ffb3cb5153c3d81bc1b", null ],
    [ "TechniqueIterator", "class_ogre_1_1_material.html#a4969168248bff6aea70eafcf75497689", null ],
    [ "LoadingFlags", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94", [
      [ "LF_DEFAULT", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c", null ],
      [ "LF_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809", null ],
      [ "LF_ONLY_UNREFERENCED", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782", null ],
      [ "LF_ONLY_UNREFERENCED_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77", null ],
      [ "LF_PRESERVE_STATE", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c", null ],
      [ "LF_MARKED_FOR_RELOAD", "class_ogre_1_1_material.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb", null ]
    ] ],
    [ "LoadingState", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572c", [
      [ "LOADSTATE_UNLOADED", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94", null ],
      [ "LOADSTATE_LOADING", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5", null ],
      [ "LOADSTATE_LOADED", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f", null ],
      [ "LOADSTATE_UNLOADING", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e", null ],
      [ "LOADSTATE_PREPARED", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1", null ],
      [ "LOADSTATE_PREPARING", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb", null ],
      [ "LOADSTATE_UNLOADED_MARKED_FOR_RELOAD", "class_ogre_1_1_material.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062", null ]
    ] ],
    [ "Material", "class_ogre_1_1_material.html#ae3c92b81e6c247286c2304f320a368ef", null ],
    [ "~Material", "class_ogre_1_1_material.html#a2e2118319d3d7cb1610869c33ab766eb", null ],
    [ "_dirtyState", "class_ogre_1_1_material.html#afcb4a61b965600a67ca2c2f060821db9", null ],
    [ "_fireLoadingComplete", "class_ogre_1_1_material.html#a893c7a150edb48a25e5df700cfc194eb", null ],
    [ "_firePreparingComplete", "class_ogre_1_1_material.html#a77d5f72e02500f6db6f460bb48eac721", null ],
    [ "_fireUnloadingComplete", "class_ogre_1_1_material.html#a4b5d014a4d078b7893cce480b264c493", null ],
    [ "_getLodValues", "class_ogre_1_1_material.html#adda4a74d812101f23155b9ec1aa5b917", null ],
    [ "_notifyNeedsRecompile", "class_ogre_1_1_material.html#a66ab9a0f0ef89e66a0f0e0349433af39", null ],
    [ "_notifyOrigin", "class_ogre_1_1_material.html#a3d111616339484f39c9456eeec6fd843", null ],
    [ "addListener", "class_ogre_1_1_material.html#a5513ffce404b14cff72846318b018d32", null ],
    [ "applyTextureAliases", "class_ogre_1_1_material.html#a41f86ef8e5ae9e12ef802b6ff0d4d692", null ],
    [ "changeGroupOwnership", "class_ogre_1_1_material.html#aa5d6f3f7e73b77b233fc62b11f270e4d", null ],
    [ "cleanupDictionary", "class_ogre_1_1_material.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8", null ],
    [ "clone", "class_ogre_1_1_material.html#a28e13cc77ce7deb5f0cbe2388251224d", null ],
    [ "compile", "class_ogre_1_1_material.html#a1f51926064eaa39f9d85393b41bb8870", null ],
    [ "copyDetailsTo", "class_ogre_1_1_material.html#a255bc92a45a8740b388a2b3f0691ee67", null ],
    [ "copyParametersTo", "class_ogre_1_1_material.html#a3c600369ab5d6957524125c93915019f", null ],
    [ "createTechnique", "class_ogre_1_1_material.html#ae164f5f62c90e8db06de981b2d8544c0", null ],
    [ "escalateLoading", "class_ogre_1_1_material.html#a367f6fe60bb211cb4c32e3825ca67e4c", null ],
    [ "getBestTechnique", "class_ogre_1_1_material.html#afe82bb1cb1b3303078a8f750a747175c", null ],
    [ "getCompilationRequired", "class_ogre_1_1_material.html#a0473d5bf1469491e9e40a434c4817127", null ],
    [ "getCreator", "class_ogre_1_1_material.html#a1686b8aef3b2c8d3892ae453086073c4", null ],
    [ "getGroup", "class_ogre_1_1_material.html#a6cfc6014da843369b2619d1d7d807569", null ],
    [ "getHandle", "class_ogre_1_1_material.html#a2298551707debaf774d577e643ee856a", null ],
    [ "getLoadingState", "class_ogre_1_1_material.html#a1e90ade99935ef70ec5b199243bf995b", null ],
    [ "getLodValueIterator", "class_ogre_1_1_material.html#afd936b84ca57f7baba8b20d3fa1db1fc", null ],
    [ "getName", "class_ogre_1_1_material.html#a5d3962a2bef3bd77de412c8207975caf", null ],
    [ "getNumLodLevels", "class_ogre_1_1_material.html#a90e332b7e44b66bc34e3b90d810f7f2e", null ],
    [ "getNumLodLevels", "class_ogre_1_1_material.html#a329e758eca8bedadf01edc49f29c5b2e", null ],
    [ "getNumSupportedTechniques", "class_ogre_1_1_material.html#adb809a1006c92bf84746bf145add297e", null ],
    [ "getNumTechniques", "class_ogre_1_1_material.html#a6ee1fe32db9f689a522262922ffa9b39", null ],
    [ "getOrigin", "class_ogre_1_1_material.html#a8ab9418311a7b4a116139a7871e57a4b", null ],
    [ "getParamDictionary", "class_ogre_1_1_material.html#a9dffcf1a2d754e63e98770e5cf2cd9ee", null ],
    [ "getParamDictionary", "class_ogre_1_1_material.html#a3e314036bfd3198e89bd1d250f5eb6a1", null ],
    [ "getParameter", "class_ogre_1_1_material.html#a01a6e571941916969316ab23c5ee4739", null ],
    [ "getParameters", "class_ogre_1_1_material.html#acce55ed43f888d8c4c5ed5c5aaf9d1db", null ],
    [ "getReceiveShadows", "class_ogre_1_1_material.html#a75f43a20ac158be5187facacdb4b1f70", null ],
    [ "getSize", "class_ogre_1_1_material.html#a0617d9f04ca03bd25f4bde201e6ac13b", null ],
    [ "getStateCount", "class_ogre_1_1_material.html#ade85e4d5579519e4117a84789c0ae8fd", null ],
    [ "getSupportedTechnique", "class_ogre_1_1_material.html#aab0c999ce8b2680c4f2789ee07c4b837", null ],
    [ "getSupportedTechniqueIterator", "class_ogre_1_1_material.html#a96a7e49668804887511eeb1af691ace0", null ],
    [ "getTechnique", "class_ogre_1_1_material.html#a837e53e86decdfff953a2b2dc2841c32", null ],
    [ "getTechnique", "class_ogre_1_1_material.html#a44edcf67725752235ef9fe490f12948e", null ],
    [ "getTechniqueIterator", "class_ogre_1_1_material.html#a2b00231e68df74a029421e1511ae97d6", null ],
    [ "getTransparencyCastsShadows", "class_ogre_1_1_material.html#ab10eb8e63b9e2b39aa2872d84a5be596", null ],
    [ "getUnsupportedTechniquesExplanation", "class_ogre_1_1_material.html#ac6b381037411a605cd704de9e55dbe1b", null ],
    [ "getUserLodValueIterator", "class_ogre_1_1_material.html#aab7875efbb7e2b0e5fed198469035a31", null ],
    [ "isBackgroundLoaded", "class_ogre_1_1_material.html#a60ce96525ac730a0f7b466ed287beef3", null ],
    [ "isLoaded", "class_ogre_1_1_material.html#a74138c0203835513613af73cdb08890d", null ],
    [ "isLoading", "class_ogre_1_1_material.html#a3af26f716731b64850ea50cfa4d2edef", null ],
    [ "isManuallyLoaded", "class_ogre_1_1_material.html#a8f541900f7e1f73f4c313a732199029a", null ],
    [ "isPrepared", "class_ogre_1_1_material.html#a0779c46df96234b6619a5f57fbb36078", null ],
    [ "isReloadable", "class_ogre_1_1_material.html#a8eb34a9034aab62fd537c021a79e3366", null ],
    [ "isTransparent", "class_ogre_1_1_material.html#a00967b56ec980480ba12dc6002462c3b", null ],
    [ "load", "class_ogre_1_1_material.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
    [ "markForReload", "class_ogre_1_1_material.html#a6bdd32464ce1df547d34a0739e4c3592", null ],
    [ "operator delete", "class_ogre_1_1_material.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_material.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_material.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_material.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_material.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_material.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_material.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_material.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_material.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_material.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "operator=", "class_ogre_1_1_material.html#adf305ba79f03280e53bf8b2f29b8085e", null ],
    [ "prepare", "class_ogre_1_1_material.html#a350b287fa3e83a389221274f68760008", null ],
    [ "reload", "class_ogre_1_1_material.html#a5016aec1762b026997ddd346775879ef", null ],
    [ "removeAllTechniques", "class_ogre_1_1_material.html#a1158a82d9399448666ea415d5f9a10a9", null ],
    [ "removeListener", "class_ogre_1_1_material.html#a3c49142f739ba8fb56d6e7b3db235fb7", null ],
    [ "removeTechnique", "class_ogre_1_1_material.html#a8a81c60f958b0f3615c8690583c10d52", null ],
    [ "setAmbient", "class_ogre_1_1_material.html#af2788cd021eba0164ff6020de64d417e", null ],
    [ "setAmbient", "class_ogre_1_1_material.html#a51a76c34cc1ae2a069c6d6440738d291", null ],
    [ "setBackgroundLoaded", "class_ogre_1_1_material.html#ae0a0007de944eb3c2f933a372a752b35", null ],
    [ "setBlendblock", "class_ogre_1_1_material.html#a50c4d80faff3e45ed06b62b7b8c93a9a", null ],
    [ "setColourWriteEnabled", "class_ogre_1_1_material.html#ab88f2abf1ca49a99555820fce32f75a0", null ],
    [ "setDiffuse", "class_ogre_1_1_material.html#ac074b3eb66c45685be8fb4b0ebbebcd6", null ],
    [ "setDiffuse", "class_ogre_1_1_material.html#aebf26724438956ed04cdc0834f088567", null ],
    [ "setFog", "class_ogre_1_1_material.html#a32937d27d1a0211a76d9ce8035a221ee", null ],
    [ "setLodLevels", "class_ogre_1_1_material.html#a968ff717c90173b577501bb9d700c9b3", null ],
    [ "setMacroblock", "class_ogre_1_1_material.html#ac1363fecebbacd68cdbf0f8ddef39c06", null ],
    [ "setManuallyLoaded", "class_ogre_1_1_material.html#a82174dc4f4a0645332483ced7904c2f6", null ],
    [ "setParameter", "class_ogre_1_1_material.html#ace884b65b722ead9b920b9abf27bf815", null ],
    [ "setParameterList", "class_ogre_1_1_material.html#ae356913ccefbebc4f0119a0599a406fc", null ],
    [ "setPointSize", "class_ogre_1_1_material.html#a8c26b7ccb050d96cd031db31bf996b48", null ],
    [ "setReceiveShadows", "class_ogre_1_1_material.html#abe6a4371ce72c7bf1cf5a0c2e9259815", null ],
    [ "setSamplerblock", "class_ogre_1_1_material.html#a135d3f275d4afac7a02c327b3573acaf", null ],
    [ "setSelfIllumination", "class_ogre_1_1_material.html#a27911290eaa7990dea483f62d27c9285", null ],
    [ "setSelfIllumination", "class_ogre_1_1_material.html#a0b498763bb992542e1094a027602b2bf", null ],
    [ "setShadingMode", "class_ogre_1_1_material.html#abe72697aa6f639a23d2003fc10d3939b", null ],
    [ "setShininess", "class_ogre_1_1_material.html#a008c264b3fa918677120621d6a112f99", null ],
    [ "setSpecular", "class_ogre_1_1_material.html#ac0fd7b4c5684270dc61e57ef6ddef4f2", null ],
    [ "setSpecular", "class_ogre_1_1_material.html#a1bb1aed9081702e2b7f65d32be7caad4", null ],
    [ "setToLoaded", "class_ogre_1_1_material.html#a0389e214a82832a0c11d91babbc0d65f", null ],
    [ "setTransparencyCastsShadows", "class_ogre_1_1_material.html#a5552baf6c922eb48a981f7c51aadc5e2", null ],
    [ "touch", "class_ogre_1_1_material.html#a340e9c6140a5b0f3467596712aa122a9", null ],
    [ "unload", "class_ogre_1_1_material.html#aa31bef1bfaa87731622e56f11b548e27", null ],
    [ "MaterialManager", "class_ogre_1_1_material.html#a00bfe1380be4c044551121bbd7fb8359", null ],
    [ "SceneManager", "class_ogre_1_1_material.html#a284464b0561a6f2915f04b0245b987f0", null ],
    [ "OGRE_AUTO_MUTEX", "class_ogre_1_1_material.html#a104d9db8bfcff1f37b29157bbe070f7a", null ]
];
